Text

Struct Text 

pub struct Text<'a, S> {
    pub text: &'a str,
    pub position: Point,
    pub character_style: S,
    pub text_style: TextStyle,
}
Text drawable.

A text drawable can be used to draw text to a draw target.

See the module-level documentation for more information about text drawables and examples.

Fields

text: &'a str

The string.

position: Point

The position.

character_style: S

The character style.

text_style: TextStyle

The text style.

Implementations

Source

impl<'a, S> Text<'a, S>

pub const fn new( text: &'a str, position: Point, character_style: S, ) -> Text<'a, S>

Creates a text drawable with the default text style.

pub const fn with_text_style( text: &'a str, position: Point, character_style: S, text_style: TextStyle, ) -> Text<'a, S>

Creates a text drawable with the given text style.

pub const fn with_baseline( text: &'a str, position: Point, character_style: S, baseline: Baseline, ) -> Text<'a, S>

Creates a text drawable with the given baseline.

pub const fn with_alignment( text: &'a str, position: Point, character_style: S, alignment: Alignment, ) -> Text<'a, S>

Creates a text drawable with the given alignment.