Response

Enum Response 

#[non_exhaustive]
pub enum Response {
Show 15 variants Idle, Clicked, Pressed, Released, Focused, Defocused, Selected, Trigger, Edited, ValueChanged, Hovered, Scrolled, Disabled, User(u8), Error(GuiError),
}
Response from a widget operation.

This enum represents the various responses that a widget can return after processing an operation, such as drawing or handling interactions.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Idle

No significant response, widget is idle.



Clicked

The widget was clicked (e.g., checkbox toggled).



Pressed

The widget is currently being pressed down.



Released

The widget was released.



Focused

The widget gained focus.



Defocused

The widget lost focus.



Selected

The widget was selected (e.g., radio button, list item).



Trigger

The widget was triggered (e.g., button activated).



Edited

The widget’s content was edited.



ValueChanged

The widget’s value changed.



Hovered

The widget is being hovered over.



Scrolled

The widget was scrolled.



Disabled

The widget was disabled.



User(u8)

User-defined response with custom code.



Error(GuiError)

An error occurred during the operation.

Implementations

Source

impl Response

pub const fn is_idle(&self) -> bool

Returns true if the response is idle.

pub const fn is_clicked(&self) -> bool

Returns true if the response is clicked.

pub const fn is_pressed(&self) -> bool

Returns true if the response is pressed.

pub const fn is_released(&self) -> bool

pub const fn is_focused(&self) -> bool

Returns true if the response is focused.

pub const fn is_defocused(&self) -> bool

Returns true if the response is defocused.

pub const fn is_selected(&self) -> bool

Returns true if the response is selected.

pub const fn is_trigger(&self) -> bool

Returns true if the response is trigger.

pub const fn is_edited(&self) -> bool

Returns true if the response is edited.

pub const fn is_value_changed(&self) -> bool

Returns true if the response indicates a value change.

pub const fn is_hovered(&self) -> bool

Returns true if the response is hovered.

pub const fn is_scrolled(&self) -> bool

Returns true if the response is scrolled.

pub const fn is_disabled(&self) -> bool

Returns true if the response is disabled.

pub const fn is_user(&self) -> bool

Returns true if the response is a user-defined response.

pub fn user_code(&self) -> Option<u8>

Returns the user code if the response is a user-defined response.

pub fn error(&self) -> Option<GuiError>

Returns the error if the response is an error.

Source

impl Response

pub fn from_error(error: GuiError) -> Response

Creates a response from a GUI error.

Arguments
  • error - The error to convert into a response.
Returns

Response::Error(error).

pub fn from_change(change: bool) -> Self

Creates a response based on a change flag.

Arguments
  • change - true if a change occurred, false otherwise.
Returns

Response::ValueChanged if change is true, Response::Idle otherwise.