Background

Struct Background 

pub struct Background<ID: WidgetId> { /* private fields */ }
Background widget that clears the entire screen.

This widget clears the entire background area of the UI using the background color from the current style. It’s typically used as the first widget in a UI layout to ensure a clean background.

Type Parameters

  • ID - The widget ID type implementing WidgetId

Implementations

Source

impl<ID: WidgetId> Background<ID>

pub const fn new(widget_id: ID) -> Background<ID>