Label

Struct Label 

pub struct Label<'a, ID, COL: PixelColor> { /* private fields */ }
Text label widget for displaying static text.

This widget displays a text string within a specified region with customizable font, horizontal alignment, and color. The text is automatically positioned based on the alignment setting.

Type Parameters

  • 'a - The lifetime of the text string reference
  • ID - The widget ID type implementing WidgetId
  • COL - The pixel color type implementing PixelColor

Implementations

Source

impl<'a, ID: WidgetId, COL: PixelColor> Label<'a, ID, COL>

pub const fn new(region: &'a Region<ID>, text: &'a str) -> Label<'a, ID, COL>

pub const fn with_font(self, font: UiFont<'a>) -> Self

pub const fn with_align(self, align: HorizontalAlign) -> Self

pub const fn with_color(self, color: COL) -> Self