Module plaintext

Module plaintext 

Plain text widget for displaying multi-line text.

This module provides a text widget that displays multi-line text with support for paragraph spacing, padding, and borders.

Structs

PlainText
Multi-line text widget with advanced formatting.