PlainText

Struct PlainText 

pub struct PlainText<'a, ID, COL: PixelColor> { /* private fields */ }
Multi-line text widget with advanced formatting.

This widget displays multi-line text with support for paragraph spacing, inner and outer padding, and optional borders. It uses the embedded_text crate for text rendering with automatic line wrapping.

Type Parameters

  • 'a - The lifetime of the text string reference
  • ID - The widget ID type implementing WidgetId
  • COL - The pixel color type implementing PixelColor

Implementations

Source

impl<'a, ID: WidgetId, COL: PixelColor> PlainText<'a, ID, COL>

pub const fn new( region: &'a Region<ID>, text: &'a str, ) -> PlainText<'a, ID, COL>

pub const fn with_font(self, font: UiFont<'a>) -> Self

pub const fn with_align(self, align: HorizontalAlign) -> Self

pub const fn with_color(self, color: COL) -> Self

pub const fn with_paragraph_spacing(self, paragraph_spacing: u8) -> Self

pub const fn with_padding(self, inner: u8, outer: u8) -> Self

pub const fn with_border(self, border_width: u8) -> Self