StaticImage

Struct StaticImage 

pub struct StaticImage<'a, ID, T> { /* private fields */ }
Static image widget for displaying images.

This widget displays a static image within a specified region. The image can be shown or hidden dynamically using the visible() method.

Type Parameters

  • 'a - The lifetime of the image data reference
  • ID - The widget ID type implementing WidgetId
  • T - The image type implementing ImageDrawable

Implementations

Source

impl<'a, ID: WidgetId, T: ImageDrawable> StaticImage<'a, ID, T>

pub const fn new(region: &'a Region<ID>, raw_img: &'a T) -> Self

pub const fn visible(self, show: bool) -> Self