Module staticline

Module staticline 

Static line widget for drawing lines.

This module provides a widget that draws a static line (horizontal or vertical) within a specified region with customizable width, length, padding, and color.

Structs

OriHorizontal
Marker type for horizontal line orientation.
OriVertical
Marker type for vertical line orientation.
StaticLine
Static line widget for drawing lines.