macro_rules! region_id {
($name:ident, [$first:ident, $($rest:ident),+ $(,)?]) => { ... };
}Expand description
Creates a region ID enum starting from 0.
This macro generates an enum with the specified name and variants, implementing
the WidgetId trait. It calls region_id_with_start! with a start value of 0.
Usage
use matrix_gui::region_id;
use matrix_gui::prelude::*;
region_id!(Button, [Ok, Cancel, Reset]);This will generate a Button enum with variants Ok, Cancel, and Reset
starting from 0.