Matrix GUI Prelude
This module provides a convenient way to import commonly used matrix_gui items.
Usage:
use matrix_gui::prelude::*;Re-exports
pub use crate::ui::GuiError;pub use crate::ui::GuiResult;pub use crate::ui::HorizontalAlign;pub use crate::ui::Response;pub use crate::ui::Ui;pub use crate::ui::Widget;pub use crate::ui_font::UiFont;pub use crate::ui_font::UiTextStyle;pub use crate::animation::ANIM_SCALE;pub use crate::animation::Anim;pub use crate::animation::AnimId;pub use crate::animation::AnimInstance;pub use crate::animation::AnimManager;pub use crate::animation::AnimOptions;pub use crate::animation::AnimState;pub use crate::animation::AnimStatus;pub use crate::animation::Easing;pub use crate::widget_state::RenderState;pub use crate::widget_state::RenderStatus;pub use crate::widget_state::WidgetId;pub use crate::widget_state::WidgetStates;pub use crate::region;pub use crate::region::Region;pub use crate::widgets::background::Background;pub use crate::widgets::bar::Bar;pub use crate::widgets::label::Label;pub use crate::widgets::listbox::ListBox;pub use crate::widgets::plaintext::PlainText;pub use crate::widgets::staticimage::StaticImage;pub use crate::widgets::staticline::OriHorizontal;pub use crate::widgets::staticline::OriVertical;pub use crate::widgets::staticline::StaticLine;pub use crate::style::Style;pub use paste;pub use crate::helper::lw_geometry::*;pub use crate::helper::lw_primitives::*;pub use crate::helper::*;pub use crate::i18n::*;
Macros
- rgb565
- Macro to create Rgb565 colors from 24-bit RGB values, eg.
rgb565!(0xRRGGBB)
Structs
- Angle
- Angle.
- Pixel
- A single pixel.
- Point
- 2D point.
- Primitive
Style - Style properties for primitives.
- Primitive
Style Builder - Primitive style builder.
- Rectangle
- Rectangle primitive
- Rgb565
- Rgb565 color.
- Rounded
Rectangle - Rounded rectangle primitive.
- Size
- 2D size.
- Text
- Text drawable.
Enums
- Anchor
Point - Anchor point.
- Baseline
- Text baseline.
- Binary
Color - Binary color.
Traits
- Angle
Unit - AngleUnit trait.
- Contains
Point - Trait to check if a point is inside a closed shape.
- Contiguous
Iterator Ext - Extension trait for contiguous iterators.
- Dimensions
- Adds the ability to get the bounding box of an item.
- Draw
Target - A target for embedded-graphics drawing operations.
- Draw
Target Ext - Extension trait for
DrawTargets. - Drawable
- Marks an object as “drawable”. Must be implemented for all graphics objects
- Gray
Color - Grayscale color.
- Image
Drawable - Image drawable.
- Image
Drawable Ext - Extension trait for image drawables.
- Into
Storage - Convert a
PixelColorinto its underlying storage type - Offset
Outline - Offset outline trait.
- Origin
Dimensions - Dimensions with
top_leftof the bounding box at(0, 0). - Pixel
Color - Pixel color trait.
- Pixel
Iterator Ext - Extension trait for pixel iterators.
- Points
Iter - Create an iterator over all points in the primitive.
- Primitive
- Primitive trait
- RawData
- Trait implemented by all
RawUxtypes. - RgbColor
- RGB color.
- Transform
- Transform operations
- WebColors
- Named colors as defined in the CSS specification.
- _
- Trait to convert colors into a byte array.