pub struct Region<ID> { /* private fields */ }Expand description
A region representing a rectangular area with an associated widget ID.
This struct is used to define the position and size of widgets within the GUI.
Implementations
Sourceimpl<ID: WidgetId> Region<ID>
impl<ID: WidgetId> Region<ID>
Sourcepub const fn new(id: ID, x: i16, y: i16, w: u16, h: u16) -> Self
pub const fn new(id: ID, x: i16, y: i16, w: u16, h: u16) -> Self
Creates a new region with the specified ID and dimensions.
Arguments
id- The widget ID for this regionx- The x-coordinate of the top-left cornery- The y-coordinate of the top-left cornerw- The width of the regionh- The height of the region
Sourcepub const fn new_with_area(id: ID, area: LwRectangle<i16, u16>) -> Self
pub const fn new_with_area(id: ID, area: LwRectangle<i16, u16>) -> Self
Creates a new region with the specified ID and area.
Sourcepub const fn zero(id: ID) -> Self
pub const fn zero(id: ID) -> Self
Creates a new region with zero dimensions at the origin.
Arguments
id- The widget ID for this region
Sourcepub const fn replace_id(&self, id: ID) -> Self
pub const fn replace_id(&self, id: ID) -> Self
Replace the widget ID of the region.
Sourcepub fn delta_resize(&self, delta: DeltaResize) -> Region<ID>
pub fn delta_resize(&self, delta: DeltaResize) -> Region<ID>
Returns a new region resized according to the specified delta.
Arguments
delta- The resize delta to use for resizing
Sourcepub fn resized(
&self,
width: u16,
height: u16,
anchor_point: AnchorPoint,
) -> Self
pub fn resized( &self, width: u16, height: u16, anchor_point: AnchorPoint, ) -> Self