pub struct Background<ID: WidgetId> { /* private fields */ }Expand description
Background widget that clears the entire screen.
This widget clears the entire background area of the UI using the background color from the current style. It’s typically used as the first widget in a UI layout to ensure a clean background.
Type Parameters
ID- The widget ID type implementingWidgetId
Implementations
Sourceimpl<ID: WidgetId> Background<ID>
impl<ID: WidgetId> Background<ID>
pub const fn new(widget_id: ID) -> Background<ID>