Bar

Struct Bar 

pub struct Bar<'a, ID, COL: PixelColor> { /* private fields */ }
Horizontal progress bar widget.

This widget displays a horizontal progress bar showing a value within a specified range. The bar is divided into filled and unfilled portions with customizable colors and optional border.

Type Parameters

  • 'a - The lifetime of the region reference
  • ID - The widget ID type implementing WidgetId
  • COL - The pixel color type implementing PixelColor

Implementations

Source

impl<'a, ID: WidgetId, COL: PixelColor> Bar<'a, ID, COL>

pub const fn new( region: &'a Region<ID>, min_value: i16, max_value: i16, cur_value: i16, ) -> Bar<'a, ID, COL>

pub const fn with_padding(self, padding: Size) -> Self

pub const fn with_filled_color(self, color_filled: COL) -> Self

pub const fn with_unfilled_color(self, color_unfilled: COL) -> Self

pub const fn with_border_color(self, border_color: COL) -> Self