pub struct ListBox<'a, ID, COL: PixelColor> { /* private fields */ }Expand description
List box widget for displaying scrollable text lists.
This widget displays a scrollable list of text items with support for selection highlighting. The list can have customizable font, alignment, colors, line spacing, padding, and border.
Type Parameters
'a- The lifetime of the items array referenceID- The widget ID type implementingWidgetIdCOL- The pixel color type implementingPixelColor
Implementations
Sourceimpl<'a, ID: WidgetId, COL: PixelColor> ListBox<'a, ID, COL>
impl<'a, ID: WidgetId, COL: PixelColor> ListBox<'a, ID, COL>
pub const fn new( region: &'a Region<ID>, items: &'a [&'a str], ) -> ListBox<'a, ID, COL>
pub const fn with_start(self, start_item: u16) -> Self
pub const fn with_font(self, font: UiFont<'a>) -> Self
pub const fn with_align(self, align: HorizontalAlign) -> Self
pub const fn with_color(self, color: COL) -> Self
pub const fn with_line_spacing(self, spacing: u8) -> Self
pub const fn with_padding(self, inner: u8, outer: u8) -> Self
pub const fn with_border(self, border_width: u8) -> Self
pub const fn with_selected_item(self, selected_item: i32) -> Self