pub struct StaticImage<'a, ID, T> { /* private fields */ }Expand description
Static image widget for displaying images.
This widget displays a static image within a specified region.
The image can be shown or hidden dynamically using the
visible() method.
Type Parameters
'a- The lifetime of the image data referenceID- The widget ID type implementingWidgetIdT- The image type implementingImageDrawable
Implementations